#
# spec file for package skrooge
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2008 - 2012 Sascha Manns <saigkill@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.3.0
%define qt6_version 6.6.0

%bcond_without released
%ifarch x86_64 %{x86_64} aarch64 riscv64
# Only include WebEngine for platforms that support it
%define with_qtwebengine 1
%endif
Name:           skrooge
Version:        25.1.0
Release:        1.2
Summary:        A Personal Finance Management Tool
License:        GPL-3.0-only
Group:          Productivity/Office/Finance
URL:            https://www.skrooge.org/
Source:         https://download.kde.org/stable/skrooge/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/skrooge/%{name}-%{version}.tar.xz.sig
# https://invent.kde.org/sysadmin/release-keyring/-/blob/master/keys/smankowski@key2.asc?ref_type=heads
Source2:        skrooge.keyring
%endif
BuildRequires:  kf6-breeze-icons
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libofx-devel
BuildRequires:  qt6-sql-private-devel >= %{qt6_version}
BuildRequires:  shared-mime-info
BuildRequires:  sqlcipher-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6Archive) >= %{kf6_version}
BuildRequires:  cmake(KF6ColorScheme) >= %{kf6_version}
BuildRequires:  cmake(KF6Completion) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6ConfigWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6GuiAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6ItemViews) >= %{kf6_version}
BuildRequires:  cmake(KF6JobWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6NewStuff) >= %{kf6_version}
BuildRequires:  cmake(KF6NewStuffCore) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6NotifyConfig) >= %{kf6_version}
BuildRequires:  cmake(KF6Parts) >= %{kf6_version}
BuildRequires:  cmake(KF6Runner) >= %{kf6_version}
BuildRequires:  cmake(KF6StatusNotifierItem) >= %{kf6_version}
BuildRequires:  cmake(KF6TextTemplate)
BuildRequires:  cmake(KF6Wallet) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(PlasmaActivities)
BuildRequires:  cmake(Qt6Concurrent) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core5Compat) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Designer) >= %{qt6_version}
BuildRequires:  cmake(Qt6PrintSupport) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickWidgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Sql) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
%if 0%{?with_qtwebengine}
BuildRequires:  cmake(Qt6WebEngineWidgets) >= %{qt6_version}
%endif
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Xml) >= %{qt6_version}
Requires:       hicolor-icon-theme
Requires:       qt6-sql-sqlite >= %{qt6_version}

%description
Skrooge allows managing personal finances, powered by KDE.
It has many features and can be used to enter, follow, and
analyze expenses.

%lang_package

%prep
%autosetup -p1

%build
%if 0%{?with_qtwebengine}
%cmake_kf6 -DSKG_WEBENGINE:BOOL=TRUE -DBUILD_WITH_QT6:BOOL=TRUE
%else
%cmake_kf6 -DSKG_WEBENGINE:BOOL=FALSE -DBUILD_WITH_QT6:BOOL=TRUE
%endif

%kf6_build

%install
%kf6_install

%find_lang %{name} --with-html --all-name --with-kde

%fdupes %{buildroot}

# E: env-script-interpreter
sed -i 's#env python3#python3#' %{buildroot}%{_kf6_sharedir}/skrooge/*.py

%ldconfig_scriptlets

%files
%license COPYING
%doc CHANGELOG README.md AUTHORS
%doc %lang(en) %{_kf6_htmldir}/en/skrooge/
%{_kf6_applicationsdir}/org.kde.skrooge.desktop
%{_kf6_appstreamdir}/org.kde.skrooge.appdata.xml
%{_kf6_bindir}/skrooge*
%{_kf6_configkcfgdir}/skg*.kcfg
%{_kf6_iconsdir}/breeze*/actions/22/*.svgz
%{_kf6_iconsdir}/hicolor/*/*/*
%{_kf6_knsrcfilesdir}/skrooge_*.knsrc
%{_kf6_kxmlguidir}/*
%{_kf6_libdir}/libskgbankgui.so.*
%{_kf6_libdir}/libskgbankmodeler.so.*
%{_kf6_libdir}/libskgbasegui.so.*
%{_kf6_libdir}/libskgbasemodeler.so.*
%{_kf6_notificationsdir}/skrooge.notifyrc
# %%{_kf6_plugindir}/designer/libskgbankguidesigner.so
# %%{_kf6_plugindir}/designer/libskgbaseguidesigner.so
%dir %{_kf6_plugindir}/kf6/ktexttemplate
%{_kf6_plugindir}/kf6/ktexttemplate/grantlee_skgfilters.so
%{_kf6_plugindir}/skg_gui/
%{_kf6_plugindir}/skrooge_import/
%{_kf6_plugindir}/sqldrivers/libskgsqlcipher.so
%{_kf6_sharedir}/mime/packages/x-skg.xml
%{_kf6_sharedir}/skrooge/
%{_kf6_sharedir}/skrooge_import_backend/
%{_kf6_sharedir}/skrooge_source/

%files lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en/skrooge/

%changelog
* Sat Feb  1 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.1.0
  * Correction kde#494197: Shortcut for Setting Status to Checked
  * Correction kde#494159: Wrong decimal separator in CSV import
  * Correction kde#494516: Categories "closed" are not displayed
  * Correction kde#494023: Downloading values from yahoo fails
    HTTP Error 401: Unauthorized
  * Correction kde#494077: document History panel and better
    document viewing transactions modified by an action
  * Correction kde#498157: Inconsistent icons in the Pages
    sidebar
  * Correction: Replace yahoo source (not working) by
    Boursorama source
  * Correction: More robust copy of tables
  * Migration: Support build on qt6/kf6
  * Correction: Fix performances issue on qt6 due to
    QDateTime::fromString
* Wed Sep 25 2024 Christophe Marin <christophe@krop.fr>
- Update to 2.33:
  * Correction bug 485366: Differnce in different
    Report-Selections (kde#485366)
  * Correction bug 484156: "Monthly Report" Last month grahic
    failure (kde#484156)
  * Correction bug 489784: Importing a QIF the account type is
    changed (kde#489784)
  * Correction bug 492287: Skrooge 2.32.0 freezes while opening
    existing .skg files, but import is fast (kde#492287)
  * Correction bug 493062: Another Problem with QIF and
    Character "/" (kde#493062)
  * Correction bug: Fix mimetype of .sta file
  * Correction bug: Remove dependency on QCA. So, old password
    protected files are no more supported.
  * Correction bug: Fix translation issue in "Incomes vs
    Expenditures" dashboard widget
* Tue Apr  9 2024 Garret Wassermann <gwasser@gmail.com>
- Update to 2.32.0
  * Correction kde#475294: Import file dialog show file://
  * Correction kde#475037: Dashboard: the font in "Income &
    Expenditure" is too small and has a bad contrast
  * Correction kde#478389: doc says pointed operations display a
    half-filled square, but it's 3 horizontal dots
  * Correction kde#477688: Problem with precision when doing
    internal transfer of bitcoin
  * Correction kde#480113: Skrooge: bookmarking a page adds a &
    to the bookmark name
  * Correction kde#481144: import tracker impossible, neither from
    homebank (TAG / ETIQUETTE)
  * Correction kde#481226: Improve compliance with messages HIG
  * Correction kde#483212: Can't add links in properties
  * Correction kde#482053: Difference in different Report-Selections
* Sun Oct 15 2023 Garret Wassermann <gwasser@gmail.com>
- Update to 2.31.0
  * Correction: Cannot import more than one ISO 20022 XML
    (kde#472392)
  * Correction: Importing ISO 20022 XML creates bogus accounts
    (kde#472390)
  * Correction: In Merge imported operations, prefer fields with
    values over blank fields (kde#474391)
  * Correction: The tool to align the category of operations with
    their payees' always fills in the category of the first payee it
    found (kde#474759)
  * Correction: AppData missing in 2.30.0 tarball (kde#472061)
  * Correction: Dashboard: the font in "Income & Expenditure" is too
    small and has a bad contrast (kde#475037)
  * Correction: Failure in some cases in import qif
* Thu Aug 31 2023 Garret Wassermann <gwasser@gmail.com>
- Update to 2.30.0
  * Correction: Income&Expenditure widget don't match with
    Income&Expense report (kde#435762)
  * Correction: Stats plugin should use XDG_STATE_HOME rather than
    the hardcoded .skrooge path to store files (kde#454965)
  * Correction: Skrooge crash opening dashboard, after QML dashboard
    only introduced (kde#467153)
  * Correction: Issue with reconciliation of portfolio accounts
    (kde#467599)
  * Correction: Import via woob 3.5 (kde#468329)
  * Correction: Remove all dashboard to keep only the qml version
- Fixes to spec file due to changes in qt plugin directories
* Thu Apr 13 2023 Garret Wassermann <gwasser@gmail.com>
- Update to 2.29.0
  * Correction: User must be able to unlink the current account
    connected with a credit card account (kde#459775)
  * Correction: Merging imported operation with an existing one
    fails when both have the same property (kde#459378)
  * Correction: Skrooge seems to work better under Wayland, so
    remove broken Wayland override (kde#456895)
  * Correction: Allow to add operations to a scheduled
    operation (kde#455427)
  * Correction: Add category adds as subcategory of selected, which
    doesn't match the Name line (kde#409705)
  * Correction: Exchange rates converter no longer works (kde#463245)
  * Correction: Skrooge v2.28.0 AppImage Icons Don't show
    (kde#465335)
  * Correction: When a document is open, settings stored in the
    document (underligned) must be reload
  * Correction: Remove deprecated api for loading plugins
  * Feature: Change of XML export and addition of XML import (this
    will facilitate some other XML import like ISO 20022)
  * Feature: Import ISO 20022
  * Feature: Align the category of all single operations with the
    category of their payee (quality check + view + auto correction)
* Mon Aug  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.28.0
  * Correction: document the settings icon in a table's header to
    bring up its context menu
  * Correction: field pop-ups located weirdly,
    "##WARNING: Wayland does not support QWindow::requestActivate()",
    sometimes hangs (kde#446352)
  * Correction: Skrooge report (Line) having issues with values
    above several millions (kde#452695)
  * Feature: The "Debug" page allows to execute multi sql orders
  * Feature: Import .sta file as MT940
* Tue Jan 25 2022 Wolfgang Bauer <wbauer@tmo.at>
- Update to 2.27.0
  * Correction: 2.26.1 still installs skrooge_unit.knsrc to
    depreciated /etc/xdg/ location (kde#440271)
  * Correction: you can't tab to the number and duration fields in
    Operations "Show" table filter (kde#446353)
  * Correction: Import from Woob using Ofx (kde#446915)
  * Correction: Weeks without operation are missing in reports
  * Correction: Crash when the dashboard is closed during animation
  * Feature: New release process for appimage
  * Feature: Unit values can be negative now
    (see https://forum.kde.org/viewtopic.php?f=210&t=173318)
  * Feature: Skrooge uses now the LC_MONETARY environment variable
    to use the specific locale for currency format
- Drop redundant recommendation of the -lang package
- Add signature file and keyring
* Wed Aug 18 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the QtWebKit dependency for all archs.
* Sat Jul 24 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 2.26.1
  * Correction: import not working with woob bank 3.0 (kde#436006)
  * Correction: Help text needs to be escaped (kde#436081)
  * Correction: there's no word "reconciliate" in English, should
    be reconcile (kde#436328)
  * Correction: Downloading currency using skrooge-yahoodl.py fails
    with UnicodeDecodeError (kde#439494)
  * Correction: Small fix for FEC monthly report
  * Correction: Migration on new exchangeratesapi.io APIs. Need a
    API key now
  * Correction: Fix deprecated knsrc file location
  * Feature: Add confirmation message when an import is triggered
    by a double click on an imported file
* Sun Apr 18 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 2.25.0
  * Correction: Please make qtwebengine dependency optional
    (kde#429356)
  * Correction: %% increase calculation in dashboard account widgets
    (kde#430535)
  * Correction: changing filter criteria while grouping Operations
    by Category expands a different set of categories (kde#430242)
  * Correction: Skrooge crashes when copying tables in categories
    with subcategories unfold (kde#432423)
  * Correction: Currency download from Yahoo uses "low" instead of
    "close" (kde#433514)
  * Correction: Sub operations view's tab confusingly looks
    identical to just "Operations" (kde#435330)
  * Correction: Bookmarks are not created with tab name and icon
    (kde#435847)
  * Correction: strange appearance of Skrooge bank icon pop-up menu
    if no scrollbar (kde#422273)
  * Correction: Column combo box not visible in report in dashboard
  * Feature: opt-out accounts from the "accounts" widget in the
    Dashboard (see
    https://forum.kde.org/viewtopic.php?f=210&t=165735)
  * Feature: New dashboard layouts: by columns and with layouts in
    layouts
* Tue Dec  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.24.6. Bugs fixed:
  * kde#424728 Skrooge reconciliation should play happy
    sounds when delta is 0 and when you validate pointed
    operations
  * kde#425208 Import of .gnucash failed
  * kde#421302 Ability to create aliases for accounts to
    assist with import
  * Correction: Ledger-cli export doesn't export negative
    values in the correct format
  * Feature: In monthly reports, the templates are now able to
    filter on the selected period
  * Feature: Import Ledger
* Tue Sep 29 2020 Christophe Giboudeaux <christophe@krop.fr>
- Pull in hicolor-icon-theme for dir ownership
* Thu Aug 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Use %%cmake_build instead of %%make_jobs
* Sat Jul 18 2020 wbauer@tmo.at
- Update to 2.23.0
  * Correction: Broken transaction group after CSV import
    (kde#420557)
  * Correction: documentation references obsolete "Merge
    operations" menu item (kde#412262)
  * Correction: Jumpy tab order in Accounts entry form (kde#422154)
  * Correction: Skrooge doesn't use per-locale bank icons
    (kde#422155)
  * Correction: Tooltip in Operations view is misleading, it only
    works in Status column (kde#422311)
  * Correction: Skrooge doesn't show key error message, only
    summary error (kde#423311)
  * Correction: Drag and drop file works only for operations. Not
    for all other objects.
  * Correction: cryptocompare fails if too many values are
    requested (>2000)
  * Correction: Change icon for trackers by a "crosshairs"
  * Correction: Source ratesapi doesn't work in appimage
  * Correction: Add "Settings" description in documentation
  * Correction: Units list doesn't save font size
    (see https://forum.kde.org/viewtopic.php?f=210&t=166692)
  * Correction: Update comment of operation when suboperation of a
    single operation is modified
  * Correction: Adapt download-po.py for new svn structure
  * Feature: Add new source "exchangeratesapi.io"
  * Feature: In "Search & Process", possibility to search
    operations by number of split (ideal to search simple
    operations are push suboperation comment on operation comment)
  * Feature: New advice to align comment of operation with the
    comment of suboperation of single operations
* Fri Apr 10 2020 wbauer@tmo.at
- Update to 2.22.1
  * Correction: Date 31/12 => 02/12 (kde#417163)
  * Correction: no sounds from Skrooge flatpak app (kde#418686)
  * Correction: kdeapps "nightly" flatpak isn't using latest KDE/Qt
    runtime version 5.14 (kde#419006)
  * Correction: Set the "Date of import" and "Import balance" when
    importing from OFX
  * Correction: Merge of number of operation
  * Correction: Fix Get Hot New Stuff legacy Endpoints
  * Correction: Files not able to be checked out on Windows
  * Correction: Bad display in dashboard when all accounts of a
    type are closed
  * Correction: With last version of KDE, KMessageWidget are
    sometimes empty
  * Correction: Add missing "Full screen" menu
  * Correction: Fix "coinmarketcap" source (need an API key)
  * Correction: Remove warning due to QML dashboard
  * Feature: Add new source "cryptocompare" (need an API key)
* Mon Dec  2 2019 wbauer@tmo.at
- Update to 2.21.1
  * Correction: Import CSV fails if account is empty (kde#411958)
  * Correction: skrooge appdata.xml missing release 2.20.0
    (kde#409166)
  * Correction: No guide or tooltip for + icon in Categories form,
    and inconsistent (kde#409703)
  * Correction: skrooge appdata.xml gets warnings from
    validation-strict on flathub (kde#409165)
  * Correction: Skrooge flatpak silently fails to import anything
    from Amex QFX (kde#412494)
  * Correction: Filter for custom properties have to be prefixed
    with v_operation_display_all (kde#412831)
  * Correction: Get rid of obsolete methods
  * Correction: Build flatpak with latest libofx 0.9.15
  * Correction: Import CSV with comma when headers are forced (no
    automatic detection)
  * Correction: blank spaces at units "Internet code" (see:
    https://forum.kde.org/viewtopic.php?f=210&t=163184&p=424630&hilit=skrooge#p424630)
  * Correction: Import CSV file with footer line
  * Correction: Dashboard readability improvement (see:
    https://forum.kde.org/viewtopic.php?f=210&t=162650)
  * Feature: Support using category, account, payee  or unit
    properties in reports
  * Feature: New source of unite: ratesapi.io (see:
    https://forum.kde.org/viewtopic.php?f=210&t=162312&sid=c31044c567a38f04e7276263d3720df8)
- Drop Fix-build-with-Qt-5_13.patch, merged upstream
* Mon Aug 12 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add Fix-build-with-Qt-5_13.patch
* Sun Jul  7 2019 Jan Engelhardt <jengelh@inai.de>
- Trim filler and marketing wording from description.
* Sun Jun 23 2019 wbauer@tmo.at
- Update to 2.20.0
  * Correction: no message when Skrooge can't open .skg file given
    on command line (kde#406903)
  * Correction: skrooge command-line help "--+[URL]" doesn't match
    its behavior (kde#406904)
  * Correction: QFX Date Import (kde#406741)
  * Correction: Skrooge flatpak unintentionally builds unused tests
    (kde#407280)
  * Correction: Skrooge flatpak needs later libofx (kde#407279)
  * Correction: Importing GNUcash (Account name instead of
    AccountID) (kde#407257)
  * Correction: skrooge appdata.xml fails validation on flathub,
    needs release and content_rating tags (bug#409026)
  * Correction: aqbanking corrections:
    + Added auto repair for certain banks (Sprada, Netbank,
    Comdirect)
    + Added --disable-auto-repair command line option
    + Added --prefer-valutadate command line option
    + Removed --balance command line option
  * Correction: getNetWorth (used to compute PFS) is now computed
    by using all accounts
  * Correction: Remove color of hyperlinks in dashboard for a
    better rendering in dark theme
  * Correction: Remove broken quotes sources (BitcoinAverage,
    BitcoinCharts)
  * Correction: Better handling of the mode and comment field using
    the aqbanking import backend
  * Feature: New REGEXPCAPTURE operator in "Search & Process" to
    capture a value by regular expression
  * Feature: Import backend aqbanking allows to import accounts
    without an IBAN (See https://phabricator.kde.org/D20875)
- Build with QtWebKit on architectures that don't have QtWebEngine
* Wed Apr 24 2019 wbauer@tmo.at
- Update to 2.19.1
  * Fix QFX Date Import (kde#406741)
* Mon Apr 22 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.19.0
  Bugs fixed:
  * kde#406321 ERR-8/ERR-5 importing qfx file, "More than one object returned in
    'v_account' for 't_number='''"
  * kde#406243 Skrooge does not import share operations in QIF file correctly
  * kde#406270 Skrooge does not import investment operations in QIF correctly
  * kde#406271 Skrooge does not import description of tags in QIF file into
    Tracker comment
  * kde#406266 Skrooge does not import shares in QIF correctly
  * kde#405578 build a nightly debug Skrooge flatpak
  * kde#406488 crash importing a CSV
  * kde#406549 Edit menu in Skrooge handbook is missing Skip, adds Find; missing
    context menu documentation
  * Migration failure with sqlite >= 3.25.0 due to ALTER TABLE behavior
    modification
  * Migration failure when some i_number are NULL
  Other changes:
  * Add missing file categories_previous_period_table.html in monthly report
  * build skroogeconvert as a regular ("nongui") executable instead of an app
    bundle
  * prevent runtime discarding of the app icon if icon-from-theme lookup doesn't
    work (which it doesn't by default on OS X)
  * generate a multi-scale icon from all png icons size 256px and smaller
  * Tracker with running balance in "Operations" page
  * Better performances in payee view to compute recommended categories
  * Better performances in dashboard and monthly report when amounts by accounts
  * Better performances in dashboard to find all payee without operation
  * Better performances in "Delete payees without operation"
* Tue Feb 12 2019 wbauer@tmo.at
- Updated to 2.18.0
  * Correction: skrooge w/ -DSKG_WEBENGINE=ON:
    ui_skgtablewithgraph.h:15:10: fatal error:
    QtWebKitWidgets/QWebView: No such file or directory
    (kde#403575)
  * Correction: App crashes with segfault after second import
    (kde#403675)
  * Correction: error importing QIF File
    "SKGImportPluginQif::importFile() RC=[ERR-5]:
    SKGCategoryObject::addCategory failed because linked object is
    not yet saved in the database (kde#402330)
  * Correction: import Quicken tags from QIF as Skrooge trackers
    (kde#403725)
  * Correction: kgbasegui/skgwebview.h:28:10: fatal error:
    qwebview.h: No such file or directory (kde#403985)
  * Correction: Import KMYMONEY with non utf8 characters doesn't
    work (see https://forum.kde.org/viewtopic.php?f=210&t=156506)
  * Correction: Import KMYMONEY of scheduled operations from the
    next operation to add instead of the first one (to avoid
    duplicate)
  * Correction: Import KMYMONEY of shares with only one split must
    be done with the unit of the share
  * Correction: Nb occurrences and last date are not aligned on
    weekly schedules
  * Correction: Display all occurrences of a schedule in dashboard
    not only the first one
  * Correction: Display the currency symbol at the right place in
    scheduled operations
  * Correction: Display correctly the amount in "highlighted
    operations" in dashboard
  * Correction: The advice "Advice are very long to compute" can
    now be rejected
  * Correction: Add date in "Bank (light)" widget in html mode
  * Correction: Remove template from "Highlighted operation" widget
  * Feature: Better help for "Internet code" of sources in unit
    page
  * Feature: New MSN source of download for quotes
  * Feature: File can be made anonymous in a reversible mode
  * Feature: In "Operations" page, possibility to view all
    operations of an account + its credit cards associated
  * Feature: The number of years for forecasts based on scheduled
    operations can be choosen from settings
  * Feature: Possibility to choose the max date of schedules in
    dashboard
  * Feature: New action to skip scheduled operations
  * Feature: Possibility to skip scheduled operations from
    dashboard
  * Feature: Addition of options (Incomes, Expenditures, Transfers,
    ...) in contextual menu of graphs in "Account" page
  * Feature: Addition of options (Days, Weeks, Months, ...) in
    contextual menu of graphs in "Account" page
* Tue Dec 18 2018 wbauer@tmo.at
- Updated to 2.17.0
  * Correction: Designer plugins get installed as versioned
    libraries (kde#400695)
  * Correction: Import of Quicken 2012 .QIF file failed due to tags
    (kde#400724)
  * Correction: ERR-4/ERR-5 opening relative path to .skg from
    command line, then zombie Skrooge (kde#402031)
  * Correction: Transfer created with value at 0. Regression due to
    399672. (see
    https://forum.kde.org/viewtopic.php?f=210&t=155713&p=406978)
  * Correction: QIF import with transfer on split (see
    https://forum.kde.org/viewtopic.php?f=210&t=155614)
  * Correction: Add delay (300 ms) on text filter
  * Correction: "Search & Process" create a duplicate a duplicated
    category in some cases
  * Correction: Compliance with SQLCipher 4
  * Correction: Close SQL database in mmb import
  * Feature: Like on transfer, the ratio is requested when creating
    a share operation (see
    https://forum.kde.org/viewtopic.php?f=210&t=155605&p=406979)
  * Feature: Progress bar in taskbar
  * Feature: Support only QT >= 5.7.0
- Run spec-cleaner
* Sun Nov  4 2018 wbauer@tmo.at
- Updated to 2.16.2
  * Correction: Periodic crashes on dashboard (kde#398683)
  * Correction: [ERR-5]: Format de date non pris en charge
    importation boobank (kde#397611)
  * Correction: Grammar mistake in .po file / - s missing in simple
    (kde#399480)
  * Correction: Wrong plural form in .po-File (kde#399482)
  * Correction: Spelling mistake in .po file "Transfert" should be
    "Transfer" (kde#399483)
  * Correction: Modifying multiple selected operations into
    transfers creates empty category and tracker if not identical
    (kde#399672)
  * Correction: Ofx import must import FEE as debit
  * Correction: Document migration fails if format is "d.MM.yy 'г"
    (see: https://forum.kde.org/viewtopic.php?f=210&t=155575)
  * Correction: Inconsistency in "Incomes vs Expenditures" on sub
    operations with trackers
  * Correction: Build on windows
  * Correction: Use CPU instead CPU for QML (needed for printing)
  * Correction: Set background color on print to avoid print
    preview with black background on dark theme
  * Feature: Selection above, below or parent when delete an object
  * Performances: Solve performance issue due to new feature : More
    tooltips on "Operations" table
* Fri Aug 17 2018 wbauer@tmo.at
- Updated to 2.15.0
  * Correction: Check sqlcipher installation (issue detected on
    GENTOO) (kde#397018)
  * Correction: Crash when sort a grouped view
  * Correction: Avoid to create 2 categories with the same name
    under the same category by using drag and drop
  * Correction: Avoid too many computation in
    SKGAccountObject::getPossibleReconciliations
  * Feature: Addition of a new option to check if import has been
    broken
  * Feature: More tooltips on "Operations" table
* Fri Jun 29 2018 wbauer@tmo.at
- Updated to 2.14.0
  * Correction: Reports do not graph operations by week correctly
    (kde#394857)
  * Correction: Bad perfo in SKGAccountObject::getPossibleReconciliations
    when too many operations (kde#395328)
  * Correction: Sort on second column does not work with grouping
  * Correction: Change bootstrap url in templates
  * Correction: Better grouping for "Week", "Month", "Semester", ...
  * Correction: Report with forecast based on budget use the
    account using the most the category
  * Correction: Respan of group header must work when auto resize
    is disabled too
  * Correction: Import backend of account with "." in name
  * Correction: Remove error in boobank commands
  * Correction: Set automatically the bank account only when the
    icon is changed
  * Correction: The application is hidden when the dashboard is
    opened on an empty document
  * Correction: On operation page, the sort by the
    attribute sorts operations by date+id to have correct balances
  * Correction: Weboob backend doesn't work with option if account
    name has "id"
  * Feature: Addition of "Import date" on account object
  * Feature: Possibility to merge accounts with or without updating
    the initial balance
  * Performances: Improvement of performance of SKGTreeView::selectObjects
    and SKGTreeView::getState when grouping with many groups
* Tue May  8 2018 wbauer@tmo.at
- Updated to 2.13.0
  * Correction: Choose what to display on selection (kde#392828)
  * Correction: Simple search in "Search & Process" doesn't escape
    words
  * Correction: Add notification (sound) on all creations /
    modifications of objects
  * Feature: Possibility to open concerned operations when auto
    reconciliation failed
  * Feature: Option on report to show decimals or not
  * Feature: Option "Execute on not checked operations" on
    "Search & Process" page
  * Feature: Addition of "Reconciliation balance" attribut on
    "Account" + icon to check if previous reconciliation has been
    broken or not
  * Feature: Addition of a new option to check if reconciliation
    has been broken
- Mark license file as %%license instead of %%doc
- Use %%kf5_find_htmldocs macro to generate list of doc files, and
  remove all explicit entries from -lang package's file list
- Move english docs to the main package
* Sat Mar 17 2018 wbauer@tmo.at
- Updated to 2.12.0
  * Correction: Amount Input Changes Value Prematurely (kde#389867)
  * Correction: Date Input Field Not Localized (kde#389866)
  * Correction: Split dates aren't updated when copying previous
    entry (kde#389899)
  * Correction: Opening d/l QFX file opens new skrooge file instead
    of importing into existing - opened file (kde#390223)
  * Correction: Remove compilation warning (-Wsign-promo)
  * Correction: Can't resize the window and its width exceeds the
    screen (https://forum.kde.org/viewtopic.php?f=210&t=151023)
  * Correction: Search and process doesn't work in template mode
    with category used
    (see: https://forum.kde.org/viewtopic.php?f=210&t=150940)
  * Correction: No sound notification when an operation is created
    (see: https://forum.kde.org/viewtopic.php?f=210&t=151296)
  * Feature: All bookmarked report can be easily added to the
    dashboard with the + menu
  * Feature: New "Treemap" graph mode in reports
  * Feature: Automatic merge of payees, accounts and units when
    updated with another existing name
  * Feature: Alpha numerical values are now supported for number of
    operation
    (see: https://forum.kde.org/viewtopic.php?f=210&t=150988&p=394706)
  * Feature: Addition of a new option to display the environment
    variables used by Skrooge
* Sun Feb  4 2018 wbauer@tmo.at
- Updated to 2.11.0
  * Correction: .py scripts in /usr/bin (kde#386942)
  * Correction: Splitting Currency and Amount into separate columns
    (kde#388955)
  * Correction: Better account number in weboob import
  * Correction: Weboob import is now importing account with better
    name (use of "label")
  * Correction: Weboob import compliant with utf8
  * Correction: Failure when launching "skrooge filename.xxx" when
    filename.xxx is a file to import
  * Correction: "Switch closed" is available on unit but units are
    not closable
  * Correction: When a transfer is created only one of both
    operation has the tracker set:
    https://forum.kde.org/viewtopic.php?f=210&t=143127&p=384834#p384834
  * Correction: Export of selection when selection size > 1 doesn't
    work
  * Correction: Define alternative icons when a "poor" icon set is
    used (like by default on gnome: Tango)
  * Feature: Tips of the day are now clickable and in the main page
    (not more popup panel)
  * Feature: Skrooge knows now 100 cryptocurrencies and is able to
    download their quotation
  * Feature: Enable AA_EnableHighDpiScaling if Qt version >= 5.6
  * Performances: Better performances by resizing only visible
    columns (this is useful on payee table when category is hidden)
  * Performances: Better performances in the computation of the
    automatic category for a payee
  * Performances: Improvement of performance in
    SKGImportExportManager::findAndGroupTransfers
    11552 ms => 285 ms
* Sat Nov 11 2017 wbauer@tmo.at
- updated to 2.10.5
  * Correction: Can not load share prices for French stocks
    (kde#386594)
* Fri Nov  3 2017 wbauer@tmo.at
- updated to 2.10.3
  * Correction: Report unreadable because element outlines are too
    thick (kde#383758)
  * Correction: Operation without suboperation after a kmy import
    (kde#384119)
  * Correction: Quick fill: select/enter item does not lock payee
    (kde#375865)
  * Correction: Converting multiple operations with different
    amounts to "transfer" type changes all amounts to 0
    (kde#384801)
  * Correction: When creating multiple transfers into a different
    currency use the correct exchange rate for each date
    (kde#384802)
  * Correction: Display and edit default category for payee
    (kde#385002)
  * Correction: Wrong budget for split-operations with unaligned
    dates (kde#385277)
  * Correction: Creating many transfers to a different currency
    leads to uninterruptible series of dialog boxes (kde#384803)
  * Correction: Altered budgets aren't displayed until you reload
    the tab (kde#385990)
  * Correction: The minimum/maximum limit in account definition is
    interpreted as Primary Currency (kde#386285)
  * Correction: Bad english in help on rules
  * Correction: Memory leaks
  * Correction: The source of unit download is now able to support
    date in "en_EN" locale event if this is not the system locale.
    Mandatory for implementing a Google Finance source.
  * Correction: Don't display the page of operations when the
    import is canceled
  * Correction: Better error messages in backend import
  * Correction: Optimisation in backend import
  * Correction: Optimise html of monthly reports
  * Correction: Port from QWebKit to QWebEngine
  * Correction: Avoid to compute too many combinations (and take
    hours) when trying to do an automatic reconciliation
  * Correction: Backend import must match account with id with
    letter like this 123456A@ldl
  * Correction: Never merge 2 accounts with same name in backend
    import
  * Correction: Crash when selecting many lines in search &
    process page
  * Correction: Enable print functions only when at least one page
    is opened
  * New feature: New "Google Finance" source of download for units
  * New feature: The source of unit download can be now an external
    script
  * New feature: New import backend "weboob_coming" importing
    coming operations (can be used for card with deferred debit)
  * New feature: A payee can be closed. Then it won't be available
    in combo boxes in operation page
  * New feature: A category can be closed. Then it won't be
    available in combo boxes in operation page
  * New feature: New parameters in boobank backend to be able to
    import operations only since a specified date
  * New feature: Export ledger format
  * New feature: The tooltip of "Search" explains now how the
    entered value is understood
  * Performances: Better performances on initial load (avoid to
    intialise a document before loading one other)
* Sun Aug 13 2017 wbauer@tmo.at
- updated to 2.9.0
  * Correction: Reports table view: missing characters (kde#380235)
  * Correction: Yahoo api discontinued (kde#380232)
  * Correction: Shares always use the current rate/value. On unit
    page, you can choose if you want to see the history of the unit
    value or the history of the amount owned (kde#380187)
  * Correction: Pie chart alignment (kde#380827)
  * Correction: Failure when loading file from skrooge 1.12
    (kde#380460)
  * Correction: Add keyboard shortcut to rename bookmarks
    (kde#380821)
  * Correction: Custom banks do not use their custom icon/image
    (kde#380820)
  * Correction: Cash account is not associated with a bank
    (kde#380818)
  * Correction: Going back and forth from "fullscreen mode"
    (Ctrl+Shift+F) loses the focus on "pages" tab on the left
    sidebar (kde#380802)
  * Correction: Dashboard portfolio widget: Wrong percentage values
    (kde#381056)
  * Correction: csv file import: unable to detect matching account
    (kde#381562)
  * Correction: Change tab order of properties editor (kde#381168)
  * Correction: Income & Expenditure widget does not match
    corresponding report (kde#381847)
  * Correction: Wrong budget in root categories if subcategories
    also include subcategories (kde#382162)
  * Correction: Multithreading SQL connections must be compliant
    with SQLite mode
  * Correction: Temporary skg file protected by password are not
    well restore
  * Correction: Replacement of missing icons
  * Correction: Auto apply on advice duplicates remaining advice
  * Correction: The "duplicate" function creates operation with
    invalid creation date
  * Correction: Regular expressions for CSV import are now
    translatable
  * Correction: Values are not refreshed in amortization table
    when annual rate or insurance rate are modified
  * Correction: Zoom on dashboard widget in QML doesn't work
  * Correction: No refresh of "month" in the title of some
    dashboard widgets
  * Correction: In about, the authors of sub plugins are now
    displayed
  * New feature: New import backend using aqbanking
  * New feature: Import backends can now have parameters
  * New feature: Skrooge is now able to export only the selected
    accounts or operations
  * New feature: Bulk mode in import backends
  * New feature: In "Monthly Report", possibility to get attributes
    on pointed objects
  * New feature: Addition of new BitcoinAverage source to be able
    to download bitcoin rates (due to unavailability of BitcoinCharts)
  * Performances: Avoid advice computation in dashboard when the
    dashboard is not the current page
  * Performances: Better performance in advice "Some payees seem to
    be identical"
  * Performances: Better performances on load and save
* Sun Apr 16 2017 wbauer@tmo.at
- updated to 2.8.1
  * Correction: Bad display of information of current account when
    a second document is opened
* Wed Apr  5 2017 wbauer@tmo.at
- updated to 2.8.0
  * Correction: Right-click (context menu) reload view (kde#375721)
  * Correction: Changing password does not work (kde#375875)
  * Correction: See operation for a payee (kde#375712)
  * Correction: Clear fields don't restore currency (kde#376025)
  * Correction: Quick fill: select/enter item does not lock payee
    is not well computed (kde#375865)
  * Correction: The "Other" category in dashboard and report widget
    name "5 main categories of expenditure"
  * Correction: Sometimes the sort on date in operation table is
    not the same than the sort used to compute the balance, this
    causes troubles
  * Correction: Create fake operation doesn't work on account not
    having the primary unit
    (https://forum.kde.org/viewtopic.php?f=210&t=138803&sid=d0d34f728ef7f41bb...)
  * Correction: "Income vs Expenditure" dashboard widget is not
    refreshed when data are modified
  * Correction: Bad display in "5 main categories of expenditure"
    in QML dashboard widget
  * Correction: Better performance in "Incomes vs Expenditures"
    dashboard widget
  * Correction: Duplication of operation must not duplicate the
    creation date
  * New feature 375866: Quick fill find operations in other account
  * New feature: New columns visible in operation table
  * New feature: New "budget" dashboard widget in QML
  * Performances: Better performances by using multithreading and caching
  * Performances: Better performances in "Apply all recommended corrections"
* Wed Feb  1 2017 wbauer@tmo.at
- Don't require the lang package, a recommends is enough (boo#1023095)
* Mon Jan 23 2017 wbauer@tmo.at
- updated to version 2.7.0:
  * Correction: Due to a security hole, sqlcipher is no more an
    option. If you use password protection, we strongly encourage
    you to use this version of Skrooge and to change your password
  * Correction: "Delete" and "Add property" are never activated in
    "Simulator" page
  * Correction: Current periods (Quarter, Semester, Year) must be
    available in some widgets of the dashboard
  * Correction: Only previous months are relevant in "Personal
    finance indicator" of the dashboard
  * Correction: Boobank backend does not import transactions when
    the date format is YYYY-MM-DD 00:00:00
  * Correction: Remove "Stooq monthly history.txt" because it does
    not work
  * Correction: Description of SKGPeriodEdit is not correct
  * New feature: Addition of the "Other" category in dashboard and
    report widget name "5 main categories of expenditure"
  * New feature: New grantlee filter to execute the sql order you
    want on the document. This will improve html reports
  * New feature: New grantlee filter to convert an integer in file
    size format (example: 390.2 MB)
  * New feature: Ability to open a file property by url
  * New feature: CSV export from report is now able to export raw
    values (http://forum.kde.org/viewtopic.php?f=210&t=112209&p=290153#p290153)
  * New feature: Resize of account number in "Accounts" page to be
    able to entre IBAN number
  * New feature: "Rename" for all dashboard widget
  * New feature: "Search & process" is now possible on bank name.
    This allows to create an alarm based on the deposit guarantee
    level per bank
- updated package description, skrooge is not "for KDE4"...
* Mon Jan  2 2017 wbauer@tmo.at
- updated to version 2.6.0:
  * Correction bug 372470: Scheduled transactions on dashboard
  * Correction bug 372938: merge imported operations wrong warning
    about different amounts
  * Correction bug 373147: Dashboard/Scheduled operations typo
  * Correction: Remove old skrooge icons to use the official breeze
    icons
  * Correction: Do not install namelink for private library
  * Correction: Avoid inconsistency when primary unit is not well
    defined (https://forum.kde.org/viewtopic.php?f=210&t=136856)
  * Correction: QIF import fails when non utf8 chars are found
  * Correction: Display all type of item in "Search & Process"
  * Correction: Execution of "template" rule after import destroys
    the template itself
    (https://forum.kde.org/viewtopic.php?f=210&t=137121&sid=b3336f56f03d79f50...)
  * Correction: Recovery of the working copy doesn't work in
    sqlcypher mode
  * Correction: Better performances and memory use in
    SKGAccountObject::getPossibleReconciliations
  * Correction: Better automatic account selection by using bank
    and agency numbers
  * Correction: Bad unit symbols in min and max limits in accounts
    page
  * Correction: Impossible to duplicate a page not having selection
    (eg. Dashboard, monthly report)
  * Correction: The dock "Message" is not reinitialized when a new
    file is loaded
  * Correction: In budget module, replacement of "Remove existing
    budgets" by "Remove existing budgets for xxx"
  * Correction: BitcoinCharts currency import order must be
    inverted because CSV file has been inverted
  * Correction: Better display for "Income vs Expenditure" on QML
    dashboard
  * Correction: New limit to history size set to 999 instead of 99
  * Correction: To avoid partial import with backend, the import is
    fully done in case of delta detected
  * Correction: weboob backend is now searching transactions on
    date AND rdate to avoid missing transaction
  * Correction: Skrooge is now able to download addition stuff
    (monthly report template, quote source) with knewstuff
  * Correction: Open file property fails when the property name
    contains the full path
    (https://forum.kde.org/viewtopic.php?f=210&t=137528)
  * Correction: Avoid duplicated operation when importing attached
    accounts with weboob
  * Correction: Group on suboperations must display min, average
    and maw amounts
    (https://forum.kde.org/viewtopic.php?f=210&t=137569)
  * Correction: The option "Import only operations since the last
    imported one" must not be applied with backend import
  * Correction: "Estimated interests" are now in QML in dashboard
    and are available for monthly reports
  * Correction: Addition of tooltips on each operator in "Search &
    Process"
  * New feature: Addition of "nocolor" to the "money" Grantlee
    filter
  * New feature: Remove .skg in backup file name if .skg is added
    in the prefix
    (https://forum.kde.org/viewtopic.php?f=210&t=136518&p=366065#p366065)
  * New feature: "Alarm" dashboard widget is now compliant with QML
    mode
- adjust file list
* Sat Oct  1 2016 wbauer@tmo.at
- updated to version 2.5.0
  * Correction bug 364407: Doesn't build with Qt 5.7
  * Correction bug 366025: Skrooge perpetually asks me to save
    updated tab state
  * Correction bug 368196: Delete sub-operations in edit delete
    selected operation in list
  * Correction bug 368356: Show amount sign on lost focus
  * Correction bug 368195: No lock on target account for a transfer
  * Correction bug 369090: Transfers sub operation created by
    template has wrong date
  * Correction: Migration connect from ui file to cpp file
  * Correction: Better colors of amounts in tooltips of advices
  * Correction: The 31 of the month, in budget page, "Previous
    month" does not work
  * Correction: When a second instance of Skrooge is launched with
    a file as argument, the file must be imported in the first
    instance of Skrooge
  * Correction: Since QT5.7, no more dependency on KDELibs4Support
  * correction: Dates wrong on dashboard - date format instead of
    the date itself
  * Correction: Keep properties when 2 operations are merged
  * Correction: Correction in weboob backend to avoid missing
    transactions and improve performances
  * New feature: Massive update is now available for amount in
    "Operation" page
  * New feature: Massive update is now available for date in
    "Operation" page
  * New feature: Capability to set/change order of budget rules
  * New feature: Tooltip on modified amount of budget to explain
    the reasons of modifications
  * New feature: Import of PDF invoice
* Tue Jul 26 2016 wbauer@tmo.at
- updated to version 2.4.0
  * Correction bug 359679: Building the v2.3.0 package on Arch
    Linux dies with an error 'isnan' was not declared in this scope
  * Correction bug 362231: Lost date in imported split operation
  * Correction: Corruption of document after removing the password
  * Correction: In unit page and dashboard widget the annual
    performance is now computed on a year (not with an
    extrapolation of the last performance)
  * Correction: Refresh "Interest" dashboard widget when operations
    are modified
  * Correction: Copy needed files in local when a new template (for
    monthly report) is created
  * Correction: All advices are not displayed in dashboard
  * Correction: More setPlaceholderText for better GUI
  * Correction: Responsive report is now using highchart
  * New feature: New tutorial grantlee template to learn how to
    develop a new template
  * New feature: New option to select if the dashboard must be in
    html or qml. Qml mode is still experimental
- drop patch fix-build.patch (now upstreamed)
* Wed Jun  8 2016 wbauer@tmo.at
- Own the whole %%{_kf5_plugindir}/grantlee directory instead of
  hardcoding the version number in the file list, otherwise the
  build breaks with every new grantlee5 version
* Fri May  6 2016 wbauer@tmo.at
- Added fix-build.patch from upstream to fix build for
  Factory/Tumbleweed
* Fri Mar  4 2016 suse@tleine.de
- updated to version 2.3.0
  * Correction bug kde#357081: No option to disable tray icon
  * Correction bug kde#357414: Bad display amount in split editor
  * Correction bug kde#358315: Typo in .desktop file leads to
    KRunner freeze
  * Correction: Avoid failure in kmy import when sub category
    already exists
  * Correction: Better autoreconciliation (the autoreconciliation
    can be done even when operations are not well sorted)
  * Correction: Migration to nullptr
  * Correction: Replace "XXX* yyy = new XXX" by
    "auto yyy = new XXX"
  * Correction: Thanks to regular expression, the "word" function
    is now able to interpret "N:1234" as a 2 words "N" and "1234"
  * Correction: Better icons (correction of installation for
    breeze)
  * Correction: Autoreconciliation doesn't work for accounts in
    other units than the primary
  * Correction: Better computation of the preferred currency for
    QIF import
  * Correction: After a modification or an creation the focus must
    be given to the table
  * Correction: Error when launching Skrooge from krunner
  * Correction: Bad sums in reports
  * New feature: New column "Balance import" in account page with
    an indicator to know if the account is still aligned with
    import balance
  * New feature: Check balance of accounts after import with
    backend
  * New feature: New "Personal Finance Score" in monthly reports
  * New feature: New "Personal Finance Score" in dashboard
  * New feature: Selection sum is now in the status bar
  * New feature: On tables, when the filter changes, the selection
    remains visible
  * New feature: Ctrl+Maj+V allows to validate OR UNVALIDATE the
    imported operations
- drop patch fix-desktop-file.patch (now upstreamed)
- changed back to service file instead of tar-ball
- update specfile for new icon locations
* Fri Jan 22 2016 wbauer@tmo.at
- added fix-desktop-file.patch: fix typo in .desktop file that led
  to KRunner/Plasma freeze and error message (kde#358315)
* Sat Dec 19 2015 suse@tleine.de
- updated to version 2.2.0
  * Correction bug kde#352674: SQLite version of the system not
    aligned with embedded in Qt when using sqlcipher
  * Correction bug kde#349961: Values in "Text" report are
    clickable to open corresponding operations
  * Correction bug kde#349976: Default categories for payees
  * Correction bug kde#354139: Pb when opening operations in sub-
    operation view
  * Correction bug kde#341463: Monthly reports include transfers
    between accounts and shows as income/expenses
  * Correction bug kde#354439: Re-open close account with money:
    wrong warning
  * Correction bug kde#354463: Incomes/Expenditures in monthly
    reports do not account for sub-operations of split operations
  * Correction bug kde#354424: Displayed balance is 0,00 and
    operation is ignored afterwards
  * Correction bug kde#354817: Arrows should increment/decrement
    operation number
  * Correction bug kde#355376: Category too small in split editor
  * Correction bug kde#355956: Not existent type in dashboard
  * Correction: Drag and drop file is now able to move a file
  * Correction: The WORD function of "Search & Replace" is no more
    sensible of useless space
  * Correction: Open skrooge document from desktop
  * Correction: Set open source licence on svg files
  * Correction: Correction ofx import in
    ECM_ENABLE_SANITIZERS='address' mode
  * Correction: Better print of dashboards by printing each widget
    individually
  * Correction: Better counting of pages in print function
  * Correction: Monthly reports with "default" template is now
    printed in only one page (remove page-break-before: always)
  * Correction: Monthly reports with "responsive" template must not
    print url
  * Correction: Migration from sqlite to sqlcipher mode does not
    work when the password contains the character "
  * Correction: In "Search & Process", the between function must
    work when v1<v2 and v2<v1
  * Correction: Bad installation of libraries for Qt Designer
  * Correction: The template combo box of "Search & Process" must
    be refreshed when a new template is created
  * Correction: Update of amount in split panel creates a new line
    instead of modifying last line in some cases
  * Correction: Migration from QSystemTrayIcon to
    KStatusNotifierItem
  * New feature: Properties with file are now an hyperlink in the
    tables
  * New feature: Display warning when icon is not found
- removed patch skrooge-designer-plugin-dir.patch (now upstream)
- removed patch sqlite_version.diff (now upstream)
- add /usr/share/appdata to spec-file
* Thu Nov 26 2015 cgiboudeaux@gmx.com
- Use the macros.kf5 variables.
- Fix dirs ownership.
* Mon Oct 12 2015 tittiatcoke@gmail.com
-  SQLite version of the system not aligned with embedded in Qt
  when using sqlcipher bko#352674
  * patch sqlite_version.diff
* Sat Sep 19 2015 i@marguerite.su
- update to version 2.1.1
  * Correction bug 351977: Missing Comment in desktop file
  * Correction bug 350722: Sudden date change from 20XX to 19XX
  * Correction: Upload of knewhotstuff does not work
  * Correction: Avoid performance issue when an operation is
  created very far in the future (example: 01/01/8015)
  * New feature: New source of download "GrandTrunk" better than
  yahoo finance for currencies
- changes in 2.1.0
  * Correction bug 349349: Allow to enter year with 2 digits only
  * Correction bug 349328: Bad date on split operation after fast
  edition
  * Correction bug 349327: Bad date format for sub-operation
  display in split tab
  * Correction bug 349624: Add operator on fast filter
  * Correction bug 349776: Freeze when splitting and editing a
  future operation
  * Correction bug 349329: Tools should display modifications
  before applying them
  * Correction bug 349961: Split value of operations in
  reports/exports
  * Correction bug 350154: Cannot change rate symbol (%%) position
  in Simulations panel
  * Correction bug 350722: Sudden date change from 20XX to 19XX
  * Correction bug 350937: Some words are not translated
  * Correction bug 340647: Encrypted Skrooge file is decrypted
  in-place
  * Correction: Authorize only word characters and space in name
  of templates of reports
  * Correction: Authorize only word characters and space in name
  of source of quotes
  * Correction: Missing unit symbol in monthly report
  * Correction: Failure on export
  * Correction: Bad display in period selector of
  "Income & Expenditure" dashboard widget
  * Correction: Bad filters in some open file dialog
  * Correction: Error when open link with non ASCII characters
  * Correction: Better detection of unaligne dates between
  operations and sub operations
  * Correction: The first update of monthly report must take into
  account the selected template instead of using the default one
  * Correction: Add credits page in "About"
  * Correction: Double click on skrooge document opens skrooge
  but the document is not loaded
  * Correction: Code rework for contextual menus
  * New feature: "Open..." action in contextual menu of reports
  * New feature: New function to import simple rules
  (payee=xxx => category=yyy) from csv file
  * New feature: More period options in dashboard widgets
  * New feature: "5 main categories of expenditure" in dashboard
  and report is now clickable
  * New feature: "Quotes" in dashboard and report is now clickable
  * New feature: Addition of list of key users in credits
  * New feature: Messages/errors can have associated action
  * New feature: "Open operations modified by this transaction"
- changes in version 2.0.0
  * Correction bug 347762: Invalid error message for SQLite
  version check after an update of SQLite
  * Correction bug 324653: Auto-Hide Scrollbars for Report Graphs
  * Correction bug 348865: Don't show translated tooltip
  * Correction bug 348490: Split with almost 0 operation
  * Correction: Porting on KF5 / QT5
  * Correction: Use of Q_DECL_OVERRIDE
  * Correction: Bad account selected in editor when a closed
  operation is selected
  * New feature: Close action available in menu and contectual menu
- add patch skrooge-designer-plugin-dir.patch
  * fix libskg(base|bank)guidesigner.so plugin install path
* Sun Jun  7 2015 thomas@tleine.de
- updated to version 1.12.5 stable
  * Correction bug kde#348619: Freeze amount should freeze unit
  * Correction bug kde#348621: Field order with tab key
  * Correction bug kde#348620: Display of multiple operations with
    common fields
  * Correction bug kde#348568: Payee with operations in 0 operation
    group
  * Correction bug kde#345994: Bad unit on some operation after
    search
  * Correction: Build for QT built with -reduce-relocations
* Thu May 14 2015 thomas@tleine.de
- updated to version 1.12.0 (stable)
  * Correction bug kde#345974: Skrooge alarms keep firing up
    regardless of specified alert amount
  * Correction bug kde#346151: Fast edition don't fill operation
    sign
  * Correction bug kde#345998: Add tooltip for all history actions
  * Correction bug kde#345799: Moved then hiden column displayed
  * New feature: Automatic point operations created during
    reconciliation
  * New feature: "Simple" mode in "Search and process" page
  * Performances: Better performances on selection change in
    "operation" page
- update spec file to package appdata
* Wed Apr 29 2015 t1locs@gmail.com
- updated to version 1.11.0 (stable)
* Sat Nov  1 2014 thomas@tleine.de
- updated to version 1.10.0 (stable)
  * Correction bug kde#334626: When doing a transfer, my
    specification of + or - is ignored
  * Correction bug kde#335943: Please add column "number of
    operations" to categories view
  * Correction bug kde#336320: OFX file import duplicates the last
    12 transactions
  * Correction bug kde#338351: Reconciliation with additional
    currencies
  * Correction bug kde#338993: Change main currency fails to update
    amounts
  * Correction bug kde#338994: Currency rate not saved for
    transactions
  * Correction: Open URL does not work in unit page
  * Correction: Wrong date in message "Operation 'XXX' will be
    inserted in YYY days"
  * Correction: Auto repair of qif file not having sum of
    suboperation amount != operation amount
  * Correction: Better error message on mny import when java is not
    installed
  * Correction: Weboob0g backend is now compliant with weboob
    version 0h
  * Correction: Correction in bitcoin quote download
  * Correction: Remove duplicate in "To Account" field on
    operations
  * Correction: Import of mode for mny files
  * Correction: Better detection of transfers in mny import
  * Correction: Automatic resize of columns in "Search and Process"
    edit panel to facilitate the creation/update of rules
  * Correction: Missing template "categories_month_table"
  * Correction: For credit card account, the binding of account is
    optional
  * Correction: Remove useless "Expand All" and "Collapse All" on
    history table
  * Correction: "Add property" and "Delete" is now working on sub
    operations
  * Correction: "Highlight" is disabled on sub operations
  * New feature: The future can be added or not in "Current" or
    "Last" periods
  * New feature: Defered credit card management
  * New feature: Capacity to apply a template on operations
  * New feature: Capacity to automatically apply a template on
    operations from "Search and Process"
  * New feature: Sort of table memorize the previous sort to be
    able to sort by column 1 and column 2
  * New feature: New advice to inform the user when the monetary
    decimal symbol is not defined in KDE localization settings
  * New feature: 2 options in graphs, one for limits visibility,
    one for average visibility
  * New feature: New advice to detect similar payees
  * New feature: New advice to detect similar categories
  * New feature: Add in documentation how to use kdewallet with
    weboob backend
  * Performances: Better performances in "Possible schedule"
  * Performances: Better performances in dashboard
- updated skrooge.spec:
  * Add BuildRequires: libkactivities-devel
  * Add macro %%kde4_pimlibs_requires
* Mon Jul 14 2014 thomas@tleine.de
- Add "BuildRequires: libxslt-tools" to fix build failures
* Thu May  1 2014 thomas@tleine.de
- updated to version 1.9.0
  * Correction kde#327148: Version 1.8.0 doesn't build
  * Correction kde#328335: Wish for fixed table row header
  * Correction kde#326764: When printing hard copy of report, only
    data in view in window is printed, not full report data
  * Correction kde#329568: Simulator utility problem
  * Correction kde#329825: When opening crypted file with false
    password skrooge falsely states the file is corrupted
  * Correction kde#329876: Weboob import from paypal ignores dates
    and creates account "0"
  * Correction kde#330354: Budget forecast duplicates operation
    creation
  * Correction kde#330428: Sorting doesn't work on Reconciliation
    date in Accounts view
  * Correction kde#331191: Obsolete term „Context“ in docbook
  * Correction: Remove conflict on CTRL+C shortcut
  * Correction: Import mny does not work with space in file name
  * Correction: In case of failure during backup file creation a
    warning message is displayed instead of an error avoiding to
    save the file
  * Correction: Refresh delta during reconciliation
  * Correction: Better PDF export from Monthly report
  * Correction: Import CSV unit file with "," as separator
  * Correction: Better KMyMoney import
  * Correction: Imported "Wallet" accounts are in bank named ''
  * Correction: Avoid wrong transfert in Grisbi import
  * Correction: The option "Import only operations since the last
    imported one" uses a delay of 4 days to avoid missing
    operations due to value date
  * Correction: Avoid error in import of homebank file without
    parent attribute on categories
  * Correction: Correction for unit download with Stooq
  * New feature: More option in "Income & Expenditure" dashboard
    widget
  * New feature: New shortcuts for "Expand all" and "Collapse all"
  * New feature: Operations can be split by date
  * New feature: Imports (csv, qif) support date format like this:
    31Dec2012
  * New feature: Import CSV support now "semicolon", "comma" and
    "tab" as separator
  * New feature: Monthly report is now able to display reports on
    months, quarter, semesters and years
  * New feature: New "responsive" template for monthly reports
  * New feature: In graph, sums are now all computed
  * New feature: Pareto curve in graph
  * New feature: New "quarter" and "semester" period in graph and
    "Incomes & Expenditures" dashboard widget
  * New feature: Ability to reorder the suboperations in the split
    operation
  * New feature: Better date filtering in operation page
  * New feature: More operators is "Search" panel
- removed parts in skrooge.spec supporting oS<12.3
* Sat Oct 12 2013 thomas@tleine.de
- updated URL to http://www.skrooge.org/ in spec-file
- updated to version 1.8.0
- Bugfix & Enhancements:
  * Correction kde#319706: OFX trntype not imported, rest okay
  * Correction kde#320114: Wrong bank balance at dashboard
  * Correction kde#320112: Importing CSV operations with mixed "
    and ' text field separators
  * Correction kde#320226: Monthly report does not work due to
    missing template
  * Correction kde#320240: Impossible to enter exact amount for
    given unit in pop-up
  * Correction kde#320242: Transaction confirmation pop-up doesn't
    use defined unit value for transaction date for suggested value
  * Correction kde#320261: Dashboard "Income & expenditure": no
    values, strange colors
  * Correction kde#320157: Skrooge not working when .skg file is
    located on Samba share
  * Correction kde#320323: Add function ("rest to") In budget
  * Correction kde#320298: Default automatic format detection while
    importing a file leads to wrong entries creation
  * Correction kde#320070: Allow changing operation date through
    "Search & Process"
  * Correction kde#320716: Skrooge does not import all operations
    using weboob
  * Correction kde#320717: Use rdate instead of date in weboob
    backend
  * Correction kde#319993: Please adopt application logo/icon for
    smaller resolutions ==> skrooge-mini can be choosen for small
    resolutions
  * Correction kde#319990: Please fix icon alignment in Pages tab
  * Correction kde#322306: Skrooge Crash using Forecast Schedule
  * Correction kde#322069: Designer plugins should be unversioned
    .so files
  * Correction kde#323380: Minor date bug when using the stock
    portfolio widgets
  * Correction kde#320066: Crash importing KmyMoney exported file
    from Skrooge
  * Correction kde#324972: Import fails without an error when
    account is defined in CSV
  * Correction kde#325081: Add a « Yesterday » choice in the date
    picker
  * Correction kde#325174: Importing from gnucash file doesn't
    import accounts fo types 'Mutual Fund' nor 'Credit Card'
  * Correction kde#325223: Crash when exiting skrooge
  * Correction kde#324008: Erreur when importing .mny file whith
    1.7.6BETA. Error when analysing categories.json
  * Correction kde#325675: Build error in skgfileplugin.cpp for
    openSUSE 12.2 KDE 4.9
  * Correction: KMyMoney exports does not need a check of integrity
    anymore
  * Correction: Addition of all icons in size 256 and 512
  * Correction: Block drop of a bookmark under an other bookmark
  * Correction: Bad date format detection when the second value is
    9 (example: 3/9/04)
  * Correction: Remove the "Bank account " string in the name of
    the account name created by an OFX import
  * Correction: Icon for "Amount entered"
  * Correction: Authorize long number for operations like
    5490990004
  * Correction: Default graph mode = line
  * Correction: Better detection of duplicate operations after
    import
  * Correction: JSON export based on QJson
  * Correction: The setting "Import only operations since the last
    imported one" allows importation for the same date (< instead
    of <=)
  * Correction: Impossible to change state of operation from
    suboperation view
  * Correction: More permissive "Open duplicate"
  * Correction: Better setting layout for import/export
  * Correction: Import/Export minimum and maximum balance in
    KMyMoney importer
  * Correction: Import minimum balance in Grisbi importer
  * Correction: Import minimum balance in Homebank importer
  * Correction: New "weboob0g" backend compliant with the Weboob
    0.g
  * Correction: When a file is selected for the icon of the bank,
    the file name is displayed in the name of the bank
  * Correction: In simulation page, the interest are computed with
    only operations with type=currency, not with shares
  * Correction: Error when importing skg file by double clicking
    when skrooge already open
  * Correction: No more password panel when the user loads an
    invalid Skrooge file
  * Correction: In report, the forecast based on budget is
    displayed even when no operation in account
  * Correction: Shortcuts in "Show" menus
  * New feature: Notifications and  error messages are now based on
    KMessageWidget
  * New feature: The restore file is now base on KMessageWidget
  * New feature: Option to auto download from backend on opening
    file (default=false)
  * New feature: Import Microsoft Money documents (.mny) protected
    or not
  * New feature: Tarballs are not uploaded on download.kde.org
  * New feature: Addition of russian banks
  * New feature: Reopen last page closed
  * New feature: Max and min limits on accounts
  * New feature: Better and new advices based on limits of accounts
  * New feature: Sound emmission on operation creation
  * New feature: Import "Budgetary allocation" and "Fiscal year"
    from Grisbi files as properties
  * New feature: Information message explaining how to exist full
    screen mode
  * New feature: Addition of date of last reconcilation on account
  * New feature: Amount owned on unit table
  * New feature: Download date on unit table
  * New feature: New account type: Pension
  * New feature: New set of categories for french people
  * New feature: Addition of "Configure notifications..." in
    configuration menu
  * New feature: Download and add bills as property by using
    boobill (weboob)
  * New feature: Rename of property
  * New feature: Export HTML and ODT from tables
  * New feature: Automatic process to recover a corrupted file
  * Performances: Better performances in dashboard
  * Performances: Better performances in monthly report
  * Performances: Better performances in import of multi files (or
    from backend) by applying "search & process" rules only one
    time
  * Performances: Better performances in kmy export
  * Performances: Better performances by avoid to refresh
    autocompletion on widgets after light transactions
* Tue May 14 2013 thomas@tleine.de
- updated to 1.7.1
- Bugfix & Enhancements:
  * Fixed kde#319565: Bad performances on ubuntu 13.04
  * Fixed kde#316604: Income and Expense widget on the dashboard
    does not respect suboperations in split operations
  * Fixed kde#316796: Reports crash when closed normally
  * Fixed kde#279967: When automatically started at login, Skrooge
    is always displayed on all desktops
  * Fixed kde#319145: Multiple currency support still buggy
  * Enhancement in Group Operations (allow grouping more than 2
    operations, or already grouped operations)
  * Hide internal properties in "Search & process", in operation
    page and in the function "Add property"
  * Enhancement in QIF import with mixed date format
  * Correction: The advice action "Remove groups with only one
    operation" does not remove the operation but the group
  * Better performances in kmymoney import and all other imports
  * Skroogeconvert now supports files without path
    (example: skroogeconvert -in t.csv -out t.kmy)
  * Better performances of skroogeconvert in case of skg import or
    export
  * Global performances gains by using the right index on unit
    table
  * Renamed "Undo document" to "Revert document"
  * Reduce the number of messages when using backend import
  * Better support of import/export with url
  * Better merging of operations in QIF import
  * Monthly reports and main page use the general font of KDE
- New Features
  * New file format (AFB120 CFONB) can be imported
  * Open report from dashboard widgets
  * More modification functions in "Search & Process" panel for
    Payee, Account, Tracker
  * New "capitalize" function in "Search & Process" panel
  * New attributes "Unit" and "Transfer" in "Search & Process" panel
  * All update functions are now available for properties in
    "Search & Process" panel
  * New icon in tab bar to create new page
  * More attributes in line and column in reports (graph)
  * Abillty to force the date format for qif and csv imports
  * More functions in tool menu
  * More tips of the days
  * Dispay option "Hide pointed operations" in operation page
  * Ability to group tables on user defined properties
  * Ability to group tables on hidden column
  * Addition of the new currency "Bitcoin" with automatic download
    of the rate
  * In dashboard and monthly report, banks can be clicked to open
    corresponding operations
  * In report, the graph correction can be done by multiply or
    divide
* Sat Mar  2 2013 mailaender@opensuse.org
- updated to 1.6.0
  * Revamped Dashboard
  * Enhancement in import mechanism (now extensible with additional backends)
* Fri Feb 22 2013 Sascha Manns <saigkill@opensuse.org>
- added account-qml to file list
* Fri Feb 22 2013 Sascha Manns <saigkill@opensuse.org>
- commented out %%%%{_libdir}/akonadi_skroogeakonadi_ressource because
  of a "File not found" since building
* Fri Feb 22 2013 Sascha Manns <saigkill@opensuse.org>
- updated to 1.5.1
- New Features:
  o New "Process Immediately" method to process immedialetly some
    scheduled operations
  o Multiselection for "Jump to the operation" in scheduled operation
    page
  o New advice to detect non alignment of comments (operation vs
    suboperation) for simpe operations
  o New advice to detect operations without mode
  o New option Automatic refresh/Manual refresh in advice dashboard
    widget
  o New advice to switch on "Manual refresh" when advice are very long
    to compute
  o New advice to detect too complex unit definition like this: IBM =>
    $ => £ => € (not supported)
  o Possibility to do graphic reports with the bank as column of line
- Bugfixes & Enhancements:
  o Fixed kde#311252 : Creating account with existing name just modify
    the existing one
  o Fixed kde#312609 : Banks widgets at the dashboard show wrong
    values
  o Fixed kde#312671 : Compile warnings
  o Fixed kde#312859 : Searching for an empty payee doesn't seem to
    work
  o Fixed kde#313140 : Thousands of compile warnings when using
    [-pedantic] [PATCH provided by Andi Clemens]
  o Fixed kde#313141 : Adjust layout in preferences window [PATCH
    provided by Andi Clemens]
  o Fixed kde#271292 : "Set to upper" process does not work with all
    characters
  o Fixed kde#263265 : Support regexps on imported data
  o Fixed kde#313268 : Better layout fot the "comment" field in the
    operations view
  o Fixed kde#313240 : Transfers between accounts with different
    currencies show as income/expense
  o Avoid endless "wait cursor" in case of canceled load of protected
    file
  o Operations page layout with very long comments
  o Disable "Pin this page" when no page is opened
  o Disable "Print" and "Print preview" when no page is opened
  o Correction in the show menu of the operation page when only one
    account with ";" in the name
  o Pb of propagation for budget rule with Period=Current Year
  o Avoid duplicate message in notification
  o Avoid to set an operation in more than one budget item when
    "garbage" budgets are used
  o Display reconciliation field when the "Reconcile" function is
    called from the page of accounts
  o Transfers ignored by default in" "Incomes & Expenditures" widget
    and reports
  o Adapt the size of the "Account" field to the lenght of the
    accounts names
  o Set focus on "Date:" field after insertion or update of an
    operation
  o Nicer line graphs
* Wed Dec 19 2012 thomas@tleine.de
- fix build failures:
  o add libkdepimlibs4-devel to BuildRequires
  o add akonadi-specific entries to files section
* Mon Dec 17 2012 Sascha Manns <saigkill@opensuse.org>
- updated to version 1.4.0
- New Features
  o New button on unit page for opening the web site of the download
    source
  o Warning on closing non null account
  o Support for Activities
  o "Stock portfolio" in monthly report
  o "Stock portfolio" dashboard widget based on monthly report
  o Possibility to add hyperlinks in monthly reports
  o Export html in monthly reports
  o New widgets for dashboard
  o 2 new templates for monthly report are delivered by default
  o 2 new advices detecting very old values of unit and very old
    operations
  o New advice checking if budgets rules are treated
- Bugfix & Enhancements
  o kde#306517: "Incomes & expenses" widget displays a wrong sum for
    expenses
  o kde#308050: Untranslatable strings in 'Budget' Page
  o kde#308395: "list of operations" screen : inoperative filters (hide
    closed operations >1 & 2 weeks)
  o kde#310372: Word completion in the comment field in standard operation
    does not work even if it was added via split operation
  o Better colors in "Expenditures vs Icomes" dashboard widget
  o Support qif file having Type:Class with description
  o Remove "All" in operation menu when only one account is created
  o Move "Export ..." menu in "File" menu
  o Bad display of account having a "&" in operation page
  o Move "Processing" actions in the main menu named "Tools"
  o Hide title when reset filter in operation page
  o Better performances in SKGDocumentBank::computeBalances by using
    compound query
  o Avoid freeze when a very old value (example: 14-11-0012) is entered by
    error for a unit
  o Avoid freeze in reports when a very old operation (example:
    14-11-0012) is entered by error
  o "Quantity owned" in unit page does not initial amount of accounts
* Sat Aug 25 2012 Sascha Manns <saigkill@opensuse.org>
- updated to version 1.3.2
- New Features
  o Progress bar in budget table for active budgets
  o "Open report" button from search page to open report without
    saving the query
  o Option to ignore operation tracked or grouped in reports
- Bugfixes & Enhancements
  o Fixed kde#300228: Failed to import from KMyMoney file
  o Fixed kde#301137: 'To Account' of an existing money transfer is
    displayed incorrectly in edit area
  o Fixed kde#302388: Gnucash import fails: Better error message in
    case of negative value for a currency
  o Fixed kde#302502: Message for possible schedule incomplete
  o Fixed kde#303527:Support more time options for ‘show checked
    operations’
  o Fixed kde#304003: Crash when removing transaction number of
    transactions with duplicate account numbers
  o Fixed kde#304313: Importing a KMyMoney file results in error
  o Rename columns of budget table
  o Better CSV and TXT exports of tables grouped by a column
  o Better SVG export of tables
  o Restore palette in tables after print
  o Do not display disabled schedules in dashboard
  o Remove text on common icons in toolbar
  o In "Scheduled operations" page, the button "Jump to the operation"
    opens the operation page in template mode to authorize updates
  o New wording; "To be Checked" instead of "Foreseen" or "In
    Transit"; "Checked" instead of "cleared" or "validated"
  o Better mouse icon when closing pined page
  o Remove X confirmations messages when closing a document with X
    pinned pages
  o Focus on opened page from bookmarks when the current page is
    pinned
  o Allow massive accounts update
  o Avoid bad table display when grouped
* Thu Apr 26 2012 Sascha.Manns@open-slx.de
- Update to Version 1.3.0
- New Features
  * Colors in "Incomes and Expenditure" dashboard widget
  * Skrooge is now able to import file have amounts with unit
    symbole (example: -$8.35)
  * "Base 100" mode for graphs, allowing to compare the evolution
    of two items.
- Bugfix & Enhancements
  * Do not display transfers in the Dashboard Advice that warns
    about empty category
  * Fix crash on opening report
  * Do not Display Accounts Graph during Account Creation
  * Fix crash on deleting split operation
  * Fix wrong behaviour on Copy/paste comment in the table of
    a split operation
  * Better display of "Show" menu in operation table
  * Support import of gnucash file without "gnc:book"
  * FastEdition now works when more than one "operation"
    page is opened
  * Fixed Crash on QIF export when the document has 3 operations
    grouped with op1.value=-op2.value
  * Refresh graphs when unit values are modified
  * Install the grantlee filter plugin into the correct location.
  * Avoid empty "Account" page when no account exist
  * No automatic resize of columns when "auto resize" is not check
  * Amounts are now displayed with the right number of digits
    in "operation" and "account" table
* Thu Mar 15 2012 Sascha.Manns@open-slx.de
- fixed grantlee issue
* Tue Mar 13 2012 Sascha.Manns@open-slx.de
- Update to Version 1.2.0
- New Features
  o In the Search & Process plugin, values for categories, payees...
    can be new values
  o Import & Export of non local files (example:
    http://myserver/document.qif)
  o The "Shares & Indexes" widget is renamed to "Quotes"
  o Possibility to select all available Units (Objects, Currencies
    etc.) in the Quotes widget
  o Percentage modes in reports
  o "Incomes & Expenditures" widget is clickable : clicking on the
    link takes you to the corresponding operations
  o Units can be highlighted to quicky identify the most important
    ones
  o Categories can be highlighted to quicky identify the most
    important ones
  o Addition of a "Show/Hide" menu in the scheduled operations plugin,
    allowing to filter out those with no more payments expected
  o Addition of a "Show/Hide" menu in the operations tab, replacing
    the previous behaviour (combobox for accounts + checkbox for checked
    operations)
- Bugfix
  o Avoid suboperations pointing on unused category when all
    categories are deleted
  o Prevents selecting the same account for source and destination for
    Transfers
  o Hide internal properties in property dock and in the graph values
  o Advice "xxx is an old tracker" is now displayed only for trackers
    that don't have recent operations.
  o Fix inline edition on comment & mode
  o Optimisation on "anonymize" function for big files
  o Avoid duplication of some categories when search and process is
    used
  o Avoid modifications in interest table
  o Fast edition refreshs the "comment" field
  o The autocompletion list for number displays only the numbers of
    the selected account
* Thu Nov 24 2011 Sascha.Manns@open-slx.de
- Update to Version 1.1.0
- New Features
  o New type of account "Loan": transfer from/to this kind of account
    are considered as "expenditure" in reports
  o New function to remove useless values in unit (the curve is preserved
  o New tag for grantlee to be able to use standard palette. Colors of the "Default"
    template are coming from the KDE palette now.
  o Possibility to download values of units with regular expressions.
  o Possibility to create/modify monthy template directly from skrooge
  o More details in progress bar
  o New advice to find and repair operations in groups with only one operation
  o New advice to find potential monthly schedule but useless values are removed)
- Bugfix
  o kde#283683: Can not add a new operation after modifying the values on an existing one
  o kde#284220: Closed account still showing up in accounts combobox of "operations" tab
  o kde#283840: Skrooge is unable to download units for a past period, but it
    works for the current day ==> Better warning message
  o kde#284073: Expressions in splitted operation amount are not calculated
  o kde#283842: If I add today a past operation in a different unit than
    the principal, the amount calculated uses the present unit value, and
    not that of the specific date
  o kde#284752: Skrooge does not look for Grantlee at build time
  o kde#284843: OFX import does not work on UTF-8 encoded files
  o kde#285880: Cumulative amount of main categories don't appear
  o kde#286538: Renaming categories doesn't rename relevant search/process
    rules (not fixed but better error management)
- Enhancements
  o Better colors in "5 main variations" widget for dashboard
  o No more error when importing skg file with payees
  o Addition of an error message on loading of a document generated by
    amost recent version (example loading on a 1.2.0 document into Skrooge 1.1.0)
  o Addition of missing date for x axis on unit graph
  o Import homebank set types of accounts
  o Possibility to remove an empty account without warning
  o Better performances during migration
  o Change language of the document on open if the language of KDE has changed
  o Better affectation of payees and comments during gnucash import
  o Better default size of the "category" panel in the split table to
    avoid manual resizing
* Fri Aug 19 2011 Sascha.Manns@open-slx.de
- Update to Version 0.9.1
  * New Features:
  * Ability to display different accounts in different currencies
  * Enhancements in the Category edition panel, that now features a
  breadcrumb style editor
  * Differentiation between "Sum" and "Percent" mode of PIE graphs
  * Better performance for categories and budgets
  * In CSV import, if 2 "amount" columns are found then the first one is
    considered as a debit and the second one as a credit
  * During import, when in doubt, date format MM_DD is preferred to DD_MM
  * Imports are supporting dates with backslashes like 29\06\2011
  * Saving the state of 'Categories Page' ignores the resized columns with
  (Auto resize: off)
  * CSV import supports multiline file like:
    date;amount;comment;type
    "1/1/2010";1000;"transfer 1
    from account A to account B";TRANSFER
    "2/2/2010";2000;"transfer 2
    from account A to account C";TRANSFER
  * You may now customize the Toolbar, as for any other KDE Application
  * Ability yo import encrypted skrooge files
  * Better print management when many pages are open
  * Missing gsb (Grisbi) format in import file selection panel
  * Graphs in "Bank and Account" page
  * Addition of "Jump to the operation" in contextual menu of
  "Scheduled operations" page
  * Properties can be a copy of a file or a link to an existing file
  * Reverse filters : if you want to show all categories except
    "Alimentation", type "-Alimentation" in the Search field. Works for
  all pages, not only in the categories page
  * Addition of "Highlight" status on catagories and payees
  * In reports, the first columns is resizable and has a tooltip for a
  better display
  * "Expand all" and "Collapse all" in category and bookmark trees
  * An option to set a frequency of units download (once a day/week/month)
  * Properties associated by drag & drop can be copied or linked (ALT+)
  * CTRL+C enables copying the selected cells of tables
  * Bugfixes
  * kde#271294: Modifying transactions with spaces in their amounts causes them to be reset to 0
  * kde#275963: Operations imported in the primary currency unit, not the account unit
  * kde#278004: Skrooge installs library files with wrong version numbers
  * kde#278220: Wrong values in Monthly Report "Amounts in accounts"
  * Remove password when anonymize a document
  * Protection again empty date : if the user remove date string then the current date is used
* Thu Jun  9 2011 saigkill@opensuse.org
- Update to Version 0.9.0
  * Correction kde#273692: Weird overlay in each dashboard widget
  * Correction kde#268933: Category editing is tedious and confusing
  * Correction kde#270207: Cannot enter positive value (credit) for
  operations in my account
  * Correction kde#270450: Add a wallet as a distinct account
  * Correction kde#271294: Modifying transactions with spaces in their
  amounts causes them to be reset to 0
  * Correction kde#271529: Add a search box to the Categories tab
  * Correction kde#271708: Wrong account transfer merging when
  importing QIF files
  * Correction kde#272863: Allow to choose which wallet store password
  in
  * Correction kde#274777: inconsistency between amounts&nb of
  operations displayed by modules Tiers, Categories and Operations
  * Correction kde#274993: Generation of forecast in a report depends
  on the option "auto-write"
  * Correction: Error during QIF import if unit is already existing
  * Correction: Open property file with space
  * Correction: Selected items always on top in graphs
  * Correction: Symbol in legend when "Point" is the selected mode of
  graph
  * Correction: Skrooge crashes on change of icon for folders in
  bookmark dock
  * Correction: Show progress bar only when needed
  * Correction: Bad values when customized dates are changed in reports
  * Correction: Better draw of pies in graphs
  * Correction: "Antialiasing" option in settings panel + automatic
  refresh of graphs after settings modification
  * Correction: "find and group transfer" does not work if 2 operations
  with same date and same amount
  * Correction: Homebank import supports budgets and scheduled
  operation
  * Correction: Change "Context" by "Pages"
  * Correction: Better computation of forecast period for "Scheduled"
  and "Budget" modes
  * Correction: Better performance in advice for scheduled operations
  * Correction: Better proportion in reports in BUBBLE mode
  * New feature: Formula is autorized in splitted amount (must start by
  =)
  * New feature: Ensure visibility of selected items in graph
  * New feature: New logo with rupee symbol
  * New feature: New button to reset internal filter in reports
  * New feature: Settings for "Reports" to select colors
  * New feature: Information zone in budget to display budgeted amount
  based on selected budgets
  * New feature: New contextual action "New category" on categories
  * New feature: Balance and balance of the day in account widgets
  (table, dashboard)
  * New feature: Merge of an imported operation with a manual operation
  is now possible even if amounts are different
  * New feature: Button on "Scheduled operations" to jump to the
  operation template for edition
  * New feature: New advice to align scheduled operation amount with
  the last amount inserted
  * New feature: New kind of graph "stack of columns"
  * New feature: New kind of graph (values in %% of columns)
  * New feature: New setting to select the color of outline in reports
  * New feature: New setting to enable/disable balances computation
* Thu Mar 17 2011 saigkill@opensuse.org
- removed hack for moving oxygen folder to hicolor
* Thu Mar 17 2011 saigkill@opensuse.org
- Updated to Version 0.8.1
  * New Features
    o Support for mt940 files
    o select previously selected tab when closing a tab
    o Improvements in CSV imports
    o Import "Money Manager EX" file
    o Allow user to change icon on bookmarks
    o Find potential duplicate operations
    o Massive update on budgets
    o Delete is more secured.
    o Possibility to change the account of operations even when only
    operations of one account are displayed (useful for credit card)
    o Property dock is able to display all properties
    o New "About" panel using KDE 4.6 features
    o Improvement on the mass update function
    o Timeline in reports
    o Some fields are now directly editable in view
    o Completion for all fields with operators (=upper and =lower for
    the moment)
    o New graph types "stacked area", "bubble"
    o New button in "operation" page to freeze/unfreeze all fields with
    text
    o Better zoom widget in contextual menu of reports
  * Bugfix
    o kde#259417: Units graph unreadable when values are missing for
    some dates ==> "Show origin" allows to show/hide the origin of the
    graph for a better display
    o kde#259416: Report showing limits, average and tendency does not
    work in mode "Sum"
    o kde#259412: Date chooser field: keyboard shortcuts do not work
    o kde#257324: No icon for Skrooge in the Gnome menu
    o kde#261318: Amount field calculator gives too many digits
    o kde#262511: Wrong widget placement in properties subwindow
    o kde#263263: Separate field for income and expenditure when
    importing CSV files
    o kde#263716: Conversion multiple records to "transfer" type cause
    all have the same ammount
    o kde#266703: Window exceeds screen size on Netbook
    o kde#267773: Skrooge always start maximized
    o Bad fullname and cumulative amount on categories after a drag and
    drop
    o Import csv with "sign" column before "amount"
    o All items are in "Skrooge" category in "Configure shortcuts"
    o No symbol for curves of indexes
    o "XX is an old tracker" advice does not give the right result when
    after 31 december
    o GNUCash import creates sometimes "wrong" splits with values close
    to 0
    o Better initial state for the window (docks, maximized)
    o Many small correction in "interest" computation (tooltips, items
    in combo box, computation, ...)
    o Bad unit in "unit" page for units having a unit reference
    o Better tooltips in report (usefull for huge report where lines
    title is not visible)
    o Better management of codex for exports
    o Bad value when update of transfer is done from target account of
    the transfer
* Wed Dec 15 2010 bitshuffler@opensuse.org
- Updated to Version 0.8.0
  * Correction kde#250350: Impossible to update an operation of a closed tracker
  * Correction kde#250403: Dashboard "Shares & Indexes" shows wrong percentaged variation
  * Correction kde#250677: Bank account choice do not use the country information
  * Correction kde#246973: Dashboard should be more customizable
  * Correction kde#251465: Wrong totals with second currency accounts
  * Correction kde#252869: Skrooge doesn't import KMM bank names correctly
  * Correction kde#255133: Skrooge crash on ofx import (With wrong data format. Bug in libOFX)
  * Correction kde#221207: Budget and forecast for accounts
  * Correction kde#256214: Skrooge after full screen mode I have only StartPage
  * Correction kde#257322: Installation doesn't depend from "QCA OSSL plugin for libqca2" (libqca2-plugin-ossl is not optional)
  * Correction kde#258307: comment from main split operation duplicated
  * Correction kde#258621: Skrooge crashes when KDE session is closed
  * Correction: Better dashboard display by using a flow layout
  * Correction: Bookmark of report having "Columns: -- Nothing --"
  * Correction: Support of "!type:prices" for QIF import and export
  * Correction: Better export KMyMoney
  * Correction: Better detection of double during imports
  * Correction: Protection again sql injection
  * Correction: Graph redraw even on hidden tabs
  * Correction: Crash on selection of a cell when graph is hidden in reports
  * Correction: Refresh of page in case of reset default state
  * Correction: Boorkmark of "operation" page in template mode
  * Correction: In report, hide columns or lines without property
  * New feature: On reports, average and limits are available if "All values in positive" is used too
  * New feature: Download of all additional information as properties for units (new setting to activate this mode)
  * New feature: Skrooge is able to store passwords in KDE wallet (new setting to activate this mode)
  * New feature: Scheduled operations with warning are in bold in dashboard
  * New feature: Show/hide properties as a column in tables
  * New feature: Auto point of imported operations to obtain the expected final balance
  * New feature: Reorder widget in dashboard by drag & drop
  * New feature: Floating panel in dashboard to remove or zoom widgets
  * New feature: Accounts can be merged by drag & drop (useful after an import)
  * New feature: Units can be merged by drag & drop (useful after an import)
  * New feature: Automatic import of csv columns as properties based on regular expression
  * New feature: New report capabilities
  * New feature: Sub total in reports
  * New feature: New advice for bank without account
  * New feature: New icons for banks of South Africa (Thank you David)
  * New feature: OR operator (+) supported in string filters
  * New feature: New contextual menu in html pages for export as pdf, odt, image and copy
  * New feature: Possible to show/hide items in context list
  * New feature: Forecast based on budgets
  * New feature: Multi selection in report table and graph
  * New feature: New "show" button
  * New feature: Better performances on dashboard
  * New feature: Better performances on tracker page
  * New feature: New function on operation: "Merge sub operations"
  * New feature: New advice for budgets
  * New feature: Possibility to dismiss kind of advices
  * New feature: Hide tendency line column
* Wed Sep  8 2010 bitshuffler@opensuse.org
- Updated to Version 0.7.3
  * Correction kde#245847: skrooge 0.7.3: 'pow10' was not declared in this scope
  * Correction kde#213786: Account balance is not displayed
  * Correction kde#246178: Dashboard "Income & Expenses" widget counting transfers
  * Correction kde#246408: Skrooge prints hardcopy
  * Correction kde#246977: In reports from selected data the date selection should be all data
  * Correction kde#247445: Linker error in skgbasemodelertest/skgtestnodes.cpp
  * Correction kde#246976: 'Select all' option in menu edit
  * Correction kde#249955: No password request after hardware crash
  * Correction: Better management of print option (collate, nb copy, from, to, last page first)
  * Correction: Do not authorize creation of operation with "-------"
  * Correction: In report, capability to create history with of property
  * Correction: In report, do not allow hiding table or graph by resizing
  * Correction: Import QIF with !Account section containing more than one account and with D attribute (Thank you Dennis)
  * New feature: Properties with a 'http' or 'file' url as value can be opened from skrooge (useful to set bank site on an account)
  * New feature: New daskboard component to know money per bank
  * New feature: Bookmarks in a menu
  * New feature: Context in a toolbar (useful for small screen)
  * New feature: Advice widget in dashboard
  * New feature: Full screen (useful for small screen)
  * New feature: Addition of file as property by drag and drop
  * New feature: Tables are scrolled "bottom" or "top" based on sort order
* Fri Aug  6 2010 bitshuffler@opensuse.org
- Add the QCA OSSL plugin as dependency
  (http://lists.kde.org/?l=kde-extra-gear&m=128057153101411&w=2)
* Sat Jul 24 2010 saigkill@opensuse.org
- Updated to Version 0.7.2
  * Correction kde#237498: Skrooge crash on saving preferences (when system tray is not available)
  * Correction kde#238087: kAmountEdit widget in Operations plugin isn't properly localized
  * Correction kde#238477: Can't open base if partition is full
  * Correction kde#240600: Skrooge must be able to export as a sqlite database
  * Correction kde#240640: Skrooge crash after password entered - input file DELETED at failure
  * Correction kde#234597: Gnucash import issues with two accounts with the same name
  * Correction kde#240601: Skrooge must be able to export an anonymized file
  * Correction kde#243738: Import of Gnucash file that has CNY currency fails
  * Correction kde#245254: Category creation failed on first level
  * Correction: Drag & drop of categories
  * Correction: Import skg file with tracker or interest simulation
  * Correction: No XML export of tables sqlite_sequence and sqlite_stat1
  * Correction: Layouts compatible with small sceen (1024x768)
  * Correction: Open right page when click on "Estimated interest" in dashboard applet
  * New feature: Zoom on tables by using CTRL+wheel
  * New feature: Search button is "Search & process" page to be able to search operations without creating a rule
  * New feature: Click on a column in "Search & process" editor removes the column
  * New feature: CTRL+F opens the "Search & process" panel with a condition based on current selection
  * New feature: Stability of colors in graph
  * New feature: Selection of colors in graph (saved and restored)
  * New feature: "Add property" to add easily properties
  * New feature: skg files saved on a FTP server can be loaded directly from Skrooge. Save is not possible.
  * New feature: New "Payee" page
  * New feature: Merge of payees by drag & drop
  * New feature: Report plugin is able to display graph based on properties
  * New feature: Possibility to select icon file for a bank
  * New feature: Any kind of file as property
  * New feature: Go home
* Wed Jun 16 2010 saigkill@opensuse.org
- reworked Spec
  FIXME: https://bugzilla.novell.com/show_bug.cgi?id=611769
* Wed May 12 2010 tittiatcoke@gmail.com
- updated to version 0.7.1
  Features
  * Use standard KDE dialogs for password management
  * Applet for dashboard to display tip of the day
  * CSV import of splits and transfers
  * CSV import is able to oncatenate many attributes in "comment"
    or "payee"
  * CSV import can import unknown attributes as properties
  * Export XML
  * "Search & Process" is able to search, update, insert and
    delete properties
  * All currencies are now available in unit page
  * Open property picture associated to an object
  * Customisable date formats
  Bugfix
  * (bko#233895): Switching account from 1 type to another with
    multi-sel is modifying the initial balance
  * (bko#233930): QIF address field is not imported
  * (bko#234595): Better handling of category deletion ==>
    Reparent operations on parent category when a category is
    removed
  * (bko#234608): Some gnucash notes are lost during import phase
  * (bko#234771): Problem importing ofx file
  * (bko#234845): Bad Account after importing ofx
* Fri May  7 2010 tittiatcoke@gmail.com
- Added fixes for build with GCC 4.5
* Thu Apr  8 2010 saigkill@opensuse.org
- updated to Version 0.7.0
* Sat Feb  6 2010 saigkill@opensuse.org
- updated to Version 0.6.0
* Mon Jan  4 2010 saigkill@opensuse.org
- update to Version 0.5.5
* Wed Nov  4 2009 saigkill@opensuse.org
- changed %%%%files Section
* Sat Oct 24 2009 saigkill@opensuse.org
- Fixed Novell Bug #543994
* Sat Oct 24 2009 saigkill@opensuse.org
- Fixed Novell Bug #545103
- Fixed Novell Bug #549803
* Fri Oct 23 2009 saigkill@opensuse.org
- Updated to Version 0.5.3
* Thu Oct 22 2009 dmueller@suse.de
- fix typo in runtime requires
* Thu Oct 22 2009 saigkill@opensuse.org
- Fixed Runtime Requires
* Sat Oct 17 2009 saigkill@opensuse.org
- Fixed Bug Novell Bugzilla #545103
* Thu Oct 15 2009 saigkill@opensuse.org
- reworked the Spec (Requires/Obsoletes)
* Thu Oct  8 2009 saigkill@opensuse.org
- updated to Version 0.5.2
* Sun Oct  4 2009 saigkill@opensuse.org
- merged all Library Subpackages to one -libs Package.
- Specfile cleanup
- Iconfile Support for GNOME
* Mon Aug 31 2009 saigkill@opensuse.org
- updated to version 0.5.0
- Changes can shown in ChangeLog
* Fri Jul 31 2009 saigkill@opensuse.org
- added make clean
* Mon Jun  1 2009 saigkill@opensuse.org
- update to Version 0.2.9
- Changes
  + Correction kde#2787146: Single click on bookmarks
  + Correction kde#191972: Selection is not well kept
  + Correction kde#191975: Add Labels for X values in histograms and stack reports
  + Correction kde#191968: Information string on top of page is too long (no word wrap)
  + Correction kde#192687: fonts too large on report
  + Correction kde#192832: Do not take amount sign into account for transfers
  + Correction kde#191967: Skrooge must be able to display an history global and for each account.
  + Correction kde#193423: context list scrolls down only after 8 mouse molette rotation
  + Correction kde#193431: "recurrent operation" trigger can not be set on D day
  + Correction kde#193421: bugs to be registered via bug database (not email)
  + Correction kde#194650: Fast edit must work on Tracker attribute
  + Correction kde#194765: Number of operations by account must be displayed in bank plugin
  + Addition of bank icon on account combo boxes
  + Addition of Canadian dollar
  + Addition of one more view (based on selection) in operation plugin
  + Better managment of dependency between units
  + New settings on unit download
  + Skrooge tries to find the most adapted account during import file without account information inside
  + Update of nls part of data model when language is changed
  + "Open report" on an element of a report open a new report with exactly same settings than first one
  + Addition of "scheduled operations" in dashboard plugin
  + New operation editor
  + Better management of messages in status bar
  + New editor in unit plugin
  + Middle click is able to open new page from context or bookmarks
* Sun May 10 2009 saigkill@opensuse.org
- split into 4 libskg* Packages
- created devel Packages
- created lang Packages
- fixed rpmlintrc
* Mon May  4 2009 saigkill@opensuse.org
- update to version 0.2.8
- removed the Removing from  /nogo
* Mon Apr 27 2009 saigkill@opensuse.org
- added files to %%%%files
* Mon Apr 27 2009 saigkill@opensuse.org
- update to Version 0.2.7
* Sat Apr 18 2009 saigkill@opensuse.org
- added %%%%kde4_requires
* Mon Mar 30 2009 saigkill@opensuse.org
- updated to Version 0.2.6
- deleted own Desktop File and use the original
* Sat Mar 14 2009 saigkill@opensuse.org
- added rpmlintrc
* Tue Mar  3 2009 saigkill@opensuse.org
- updated to Version 0.2.4
- tweaked the libs to own Packages
* Sat Feb 28 2009 saigkill@opensuse.org
- updated to Version 0.2.3
* Mon Feb 23 2009 saigkill@opensuse.org
- fixed two RPMLint Warnings
* Fri Feb 13 2009 saigkill@opensuse.org
- update to Version 0.2.2
* Tue Feb  3 2009 saigkill@opensuse.org
- included Desktop File
- using %%%%suse_update_desktop_file
* Mon Feb  2 2009 saigkill@opensuse.org
- updated to Version 0.2.1
- used %%%%cmake_kde4
* Wed Jan 21 2009 saigkill@opensuse.org
- Upgraded to version 0.2.0
* Tue Jan 13 2009 saigkill@opensuse.org
- Removed %%%%cmake_kde4. It can't compiled with it.
* Fri Jan  9 2009 pth@suse.de
- Use cmake_kde4 macro for calling cmake
- Require %%%%kde4_runtime_requires to conform to openSUSE KDE packaging.
- Fix file list
- Use find_lang
* Fri Jan  9 2009 saigkill@opensuse.org
- updated to version 0.1.9
- inserted Makros from packman
* Wed Dec 31 2008 saigkill@opensuse.org
- renamed Packet to kde4-skrooge
* Mon Nov  3 2008 saigkill@opensuse.org
- initial Version 0.1.0 using the buildservice
